package de.intevation.gnv.state;

import java.io.Serializable;

/**
 * This interface defines the basic methods used to store multiple values with
 * a specific key and name.
 * 
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public interface InputData extends Serializable {

    /**
     * Method to Retrieve the name of this input data item.
     *
     * @return the name
     */
    public String getName();

    /**
     * Method to retrieve the value of this input data item. A value might be a
     * list of values separated by a specific character.
     *
     * @return the value
     */
    public String getValue();

    /**
     * Method to store a further object at this input data item.
     *
     * @param o A further object.
     */
    public void setObject(Object o);

    /**
     * Method to retrieve the extra object.
     *
     * @return the extra object.
     */
    public Object getObject();

    /**
     * Method to store descriptions for this input data item.
     *
     * @param description Array of descriptions.
     */
    public void setDescription(String[] description);

    /**
     * Method to retrieve a description specified by a given key.
     *
     * @param key Key.
     * @return the description for this key.
     */
    public String getDescription(String key);

    /**
     * Method to retrieve all descriptions of this input data item.
     *
     * @return descriptions.
     */
    public String[] getDescription();

    /**
     * Append a further string value to the value field devided by a separater
     * character.
     *
     * @param value Value to append.
     */
    public void concartValue(String value);

    /**
     * Method to retrieve the character separated values split into an array.
     *
     * @return
     */
    String[] splitValue();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :